@@ -16,7 +16,7 @@ import pathlib
 import time
 from datetime import datetime
 
-from typing import TYPE_CHECKING, Any, Dict, Optional, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, TypeVar, Union, cast
 
 import jsonschema.exceptions
 import yaml
@@ -331,11 +331,12 @@ class BaseActor(BaseClient):
     """
 
     model: Union[Model, None] = None
+    _message_processor: Callable[[dict], dict] | None = None
 
     def __init__(
         self,
         *args,
-        schema: SchemaType = None,
+        schema: SchemaType | None = None,
         additional_properties: bool = False,
         **kwargs,
     ):
@@ -373,6 +374,20 @@ class BaseActor(BaseClient):
 
         return self.model
 
+    def set_message_processor(self, processor: Callable[[dict], dict] | None):
+        """Sets the message processor.
+
+        Parameters
+        ----------
+        processor
+            A function that receives the messsages to output to the users, as a
+            dictionary, and reformats them, returning a new dictionary. If `None`,
+            no processing is done.
+
+        """
+
+        self._message_processor = processor
+
     @abc.abstractmethod
     def new_command(self):
         """Handles a new command.
@@ -478,6 +493,9 @@ class BaseActor(BaseClient):
 
         message.update(kwargs)
 
+        if self._message_processor:
+            message = self._message_processor(message)
+
         for key, value in message.items():
             if isinstance(value, Exception):
                 if expand_exceptions is True:
@@ -553,6 +571,6 @@ class Reply:
 
     @property
     def body(self):
-        """"Alias to ``message``."""
+        """Alias to ``message``."""
 
         return self.message
