@@ -200,7 +200,7 @@ class BaseCommand(
     def set_status(
         self,
         status: Union[CommandStatus, str],
-        message: Dict[str, Any] | str = None,
+        message: Dict[str, Any] | str | None = None,
         silent: bool = False,
         **kwargs,
     ) -> BaseCommand:
@@ -337,6 +337,8 @@ class BaseCommand(
                 return
             if message_code == ":":
                 message_code = "i"
+                if kwargs == {} and (message == {} or not message):
+                    return
             elif message_code == "f":
                 message_code = "e"
 
@@ -353,6 +355,7 @@ class BaseCommand(
         self,
         target: str,
         command_string: str,
+        new_command: bool = True,
         *args,
         **kwargs,
     ) -> BaseCommand[Actor_co, BaseCommand] | Awaitable[BaseCommand]:
@@ -365,7 +368,7 @@ class BaseCommand(
             target,
             command_string,
             *args,
-            command=self,
+            command=self if new_command is False else None,
             **kwargs,
         )
 
@@ -406,6 +409,21 @@ class Command(BaseCommand[Actor_co, "Command"]):
 
         self.transport = transport
 
+    def child_command(self, command_string):
+        """Starts a sub-command on the actor currently running this command.
+
+        The practical effect is to run another of the same actor's commands as
+        if it were part of the current `.Command`.
+
+        """
+
+        return Command(
+            command_string,
+            actor=self.actor,
+            commander_id=self.actor.name,
+            parent=self,
+        ).parse()
+
     def parse(self) -> Command:
         """Parses the command."""
 
